@@ -5,9 +5,15 @@ package org.gcube.portlets.user.td.openwidget.client;
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.core.client.EntryPoint;
 
+/**
+ * 
+ * @author "Giancarlo Panichi" 
+ * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
+ *
+ */
 public class TDOpenEntry  implements EntryPoint  {
 
-	@Override
+	
 	public void onModuleLoad() {
 		TDOpen tdopen= new TDOpen("Open Tabular Resource"); 
 		Log.info(tdopen.getId());
